# kondo-ML

kondo-ML is a package containing various instance selection algorithms
usable with regression models. The implementations are compatible with sklearn and follow
its outlier detection interface.